# Mod = (Mojo Dep)

English | [简体中文](README_CN.md)

## Intro

- [Mojo](https://docs.modular.com/mojo/) Package Manager Tool
- like:
    - Rust: `Cargo`
    - Python: `Pip/Poetry/PDM`
    - Go: `Dep + Vendor`

## Quick Start

- ✅ requirements:
    - mojo 0.6+
    - python 3.10+
    - git

```ruby
mojo -v            
mojo 0.6.1 (876ded2e)

python --version                                                                                                                                          07:27:03
Python 3.10.9

```

- ✅ install `mod`:

```ruby

pip install mod-cli

# or
poetry add mod-cli --dev

```

- ✅ Usage: (Using the `mod` command)
    - [x] `mod new`: create a new mojo project
        - `--lib`: Create a library project.
        - `--bin`: Create an application (executable binary).
    - [ ] `mod init`: Create a new mojo package in an existing directory
    - [ ] `mod build`: build a `mojopkg`
    - [ ] `mod install`: download mojo dependencies to `target/deps`
    - [ ] `mod hack`:
        - `mod hack build`: build `target/deps` dependencies into `mojopkg`
        - `mod hack install`: install `target/deps` dependencies to `mojo standard library path
        - `mod hack uninstall`: uninstall `target/deps` dependencies
        - `mod hack clean`: Clean the mojopkg (binary library) generated by compiling target/deps.
    - [ ] `mod run`: Run a mojo file.
    - [ ] `mod test`: Run unit tests.
    - [ ] `mod add`: Add a dependency.
    - [ ] `mod remove`: Remove a dependency.
    - [ ] `mod list`: List all dependencies.
    - [ ] `mod search`: Search for dependencies (fuzzy search).
    - [ ] `mod sync`: Sync dependencies.
    - [ ] `mod lint`: Code style check.
    - [ ] `mod publish`: Publish a mojo project.
    - [ ] `mod workspace`: Manage monorepo workspaces.
        - `mod workspace init`: Initialize a workspace.
        - `mod workspace list`: List workspaces.
        - `mod workspace add`: Add a workspace.
        - `mod workspace remove`: Remove a workspace.
    - [ ] `mod self`: Manage itself.
        - `mod self update`: Update the mod command itself.
    - [x] `mod help`: Show help information.

```ruby

mod --help


```

## Manual

- `mod cmds`

### ✅ Create a new project

- like `cargo new` style:

```ruby
# new a libary
mod new your/path/to/project --lib

# new a app
mod new your/path/to/project --bin
```

### ❎ Build Mojo Package

- ❎ TODO

```ruby

mod build

```

# References

- https://taskfile.dev
- typer: https://typer.tiangolo.com

> package manager

- [python + poetry](https://python-poetry.org/)
- [python + pdm](https://pdm-project.org/latest/)
- [rust + cargo](https://doc.rust-lang.org/cargo/)
- [golang + dep](https://github.com/golang/dep)